@@ -7,6 +7,7 @@ import urllib.parse
 import re
 from functools import reduce
 import requests
+import warnings
 from tabulate import tabulate
 from . import series
 from . import source
@@ -31,7 +32,8 @@ endpoint = 'https://api.worldbank.org/v2'
 lang = 'en'
 per_page = 1000          # you can increase this if you start getting 'service unavailable' messages, which can mean you're sending too many requests per minute
 db = 2
-proxies = None           # see https://requests.readthedocs.io/en/master/user/advanced/#proxies for format
+proxies = None           # deprecated
+get_options = {}         # additional parameters passed to requests.get
 
 # The maximum URL length is 1500 chars before it reports a server error. Internally we use a smaller
 # number for head room as well as to provide for the query string
@@ -518,9 +520,12 @@ def _responseObjects(url, result, wantConcepts=False):
 def _queryAPI(url):
     '''Internal function for calling the API with sanity checks
     '''
-    global proxies
+    params = get_options.copy()
+    if proxies:
+        warnings.warn('"proxies" is deprecated and will be removed in a future release. Use "get_options" instead as described in the README', DeprecationWarning)
+        params['proxies'] = proxies
 
-    response = requests.get(url, proxies=proxies)
+    response = requests.get(url, **params)
     if response.status_code != 200:
         raise APIError(url, response.reason, response.status_code)
 
